@@ -218,6 +218,14 @@ updateNifti <- function (image, template = NULL, datatype = "auto")
 #'   ANALYZE \code{originator} field to store a coordinate origin. This
 #'   interpretation is also returned, in the \code{origin} field.
 #' 
+#'   Both of these functions call \code{\link{asNifti}} on their arguments to
+#'   coerce it to NIfTI, except in one specific circumstance: when
+#'   \code{analyzeHeader} is called with a single-element character-mode
+#'   argument that is not an \code{"internalImage"} object. In this case the
+#'   string is taken to be a path and the header is reported as stored on disk.
+#'   This is because otherwise the header may be changed by the process of
+#'   converting it to NIfTI and back.
+#' 
 #' @examples
 #' niftiHeader(system.file("extdata", "example.nii.gz", package="RNifti"))
 #' 
@@ -238,7 +246,11 @@ niftiHeader <- dumpNifti <- function (image = list())
 #' @export
 analyzeHeader <- function (image = list())
 {
-    .Call("analyzeHeader", asNifti(image,internal=TRUE), PACKAGE="RNifti")
+    # Special case needed to avoid converting to NIfTI internally first
+    if (is.character(image) && length(image) == 1 && !inherits(image,"internalImage"))
+        .Call("analyzeHeader", image, PACKAGE="RNifti")
+    else
+        .Call("analyzeHeader", asNifti(image,internal=TRUE), PACKAGE="RNifti")
 }
 
 #' @rdname niftiHeader
